@@ -37,6 +37,58 @@ class OrderAPI(object):
         contents = self.get(url, currency = currency)
         return contents
 
+    def produce_order(
+        self,
+        number,
+        justification = None,
+        notify = False,
+        strict = True
+    ):
+        url = self.base_url + "orders/%d/produce" % number
+        contents = self.put(
+            url,
+            justification = justification,
+            notify = notify,
+            strict = strict
+        )
+        return contents
+
+    def ready_order(
+        self,
+        number,
+        justification = None,
+        notify = False,
+        strict = True
+    ):
+        url = self.base_url + "orders/%d/ready" % number
+        contents = self.put(
+            url,
+            justification = justification,
+            notify = notify,
+            strict = strict
+        )
+        return contents
+
+    def send_order(
+        self,
+        number,
+        justification = None,
+        notify = False,
+        strict = True,
+        tracking_number = None,
+        tracking_url = None
+    ):
+        url = self.base_url + "orders/%d/send" % number
+        contents = self.put(
+            url,
+            justification = justification,
+            notify = notify,
+            strict = strict,
+            tracking_number = tracking_number,
+            tracking_url = tracking_url
+        )
+        return contents
+
     def report_pdf(self, number):
         url = self.base_url + "orders/%d/report.pdf" % number
         contents = self.get(url, number)
